@@ -124,7 +124,7 @@ class CourseraDownloader(object):
     def trim_path_part(self, s):
         mppl = self.max_path_part_len
         if mppl and len(s) > mppl:
-            return s[:mppl - 3] + "..."
+            return s[:mppl]
         else:
             return s
 
@@ -296,13 +296,16 @@ class CourseraDownloader(object):
             headers) or filename_from_url(url)
 
         # split off the extension
-        _, ext = path.splitext(fname)
+        basename, ext = path.splitext(fname)
+
+        # ensure it respects mppl
+        fname = self.trim_path_part(basename) + ext
 
         # check if we should skip it (remember to remove the leading .)
         if ext and ext[1:] in self.ignorefiles:
             print_('    - skipping "%s" (extension ignored)' % fname)
             return
-
+        
         filepath = path.join(target_dir, fname)
 
         dl = True
@@ -464,6 +467,7 @@ class CourseraDownloader(object):
 
                 # ensure the class dir exists
                 clsdir = path.join(wkdir, clsdirname)
+
                 if not path.exists(clsdir):
                     os.makedirs(clsdir)
 
@@ -476,6 +480,7 @@ class CourseraDownloader(object):
                             classResource, target_dir=clsdir, target_fname=tfname)
                     except Exception as e:
                         print_("    - failed: ", classResource, e)
+
         if gzip_courses:
             tar_file_name = cname + ".tar.gz"
             print_("Compressing and storing as " + tar_file_name)
